period_predict: Prediction over a period of time

Description Usage Arguments Value Examples

View source: R/period_predict.R

Description

Take each day of a period of time as the starting point of prediction and get the result.

Usage

1
period_predict(datafile, M, Beginning_Time, period)

Arguments

datafile

it can be the path of data file as Charactors or be the raw data read from .csv as a dataframe.

M

the selection of time window.

Beginning_Time

the selection of beginning time, which must be in the formate "%y-%m-%d" as a character.

period

the number of days in the selected time period.

Value

List contains as many sublist as the value of param period. Each sublist is the result of a prediciton with the given time t as beginning time. And each sublist is named with the beginning time of predicion.

Examples

1
2
3
4
5
Beginning_Time <- "2020-01-29"
M <- 5
period <- 32
period_predict(DemoPreTurningPointsCOVID19::COVID19_CN, M,
Beginning_Time, period)

YuanchenZhu2020/DemoPreTurningPointsCOVID19 documentation built on Aug. 17, 2020, 12:24 a.m.