Description Usage Arguments Value Examples
View source: R/period_predict.R
Take each day of a period of time as the starting point of prediction and get the result.
1 | period_predict(datafile, M, Beginning_Time, period)
|
datafile |
it can be the path of data file as Charactors or be the raw data read from .csv as a dataframe. |
M |
the selection of time window. |
Beginning_Time |
the selection of beginning time, which must be in the formate "%y-%m-%d" as a character. |
period |
the number of days in the selected time period. |
List contains as many sublist as the value of param period. Each sublist is the result of a prediciton with the given time t as beginning time. And each sublist is named with the beginning time of predicion.
1 2 3 4 5 | Beginning_Time <- "2020-01-29"
M <- 5
period <- 32
period_predict(DemoPreTurningPointsCOVID19::COVID19_CN, M,
Beginning_Time, period)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.